@@ -2,9 +2,9 @@
 #
 #
 # Copyright (C) 2003-2013 Michael Schindler <m-schindler@users.sourceforge.net>
-# Copyright (C) 2003-2005 André Wobst <wobsta@users.sourceforge.net>
+# Copyright (C) 2003-2005 André Wobst <wobsta@pyx-project.org>
 #
-# This file is part of PyX (http://pyx.sourceforge.net/).
+# This file is part of PyX (https://pyx-project.org/).
 #
 # PyX is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -313,7 +313,7 @@ def controldists_from_endgeometry_pt(A, B, tangA, tangB, curvA, curvB, allownega
             if (t > 0 and t < x[0] and s > 0 and s < x[1]):
                 if (t > 0 and t < y[0] and s > 0 and s < y[1]):
                     # use the shorter one
-                    return (errx > erry) - (errx < erry)
+                    return int(errx > erry) - int(errx < erry)
                 else:
                     # use the longer one
                     return -1
@@ -323,10 +323,10 @@ def controldists_from_endgeometry_pt(A, B, tangA, tangB, curvA, curvB, allownega
                     return 1
                 else:
                     # use the shorter one
-                    return (errx > erry) - (errx < erry)
+                    return int(errx > erry) - int(errx < erry)
             #return cmp(x[0]**2 + x[1]**2, y[0]**2 + y[1]**2)
         else:
-            return (sy > sx) - (sy < sx)
+            return int(sy > sx) - int(sy < sx)
     # >>>
     solutions.sort(key=functools.cmp_to_key(mycmp))
 
@@ -907,11 +907,12 @@ class parallel(baseclasses.deformer): # <<<
 
         dist = self.dist_pt
         epsilon = orig_nsp.epsilon
-        assert len(orig_nsp.normsubpathitems) != 0
+
+        if len(orig_nsp.normsubpathitems) == 0:
+            return normpath.normpath([]), None, None, {}
 
         # avoid too small dists: we would run into instabilities
         if abs(dist) < abs(epsilon):
-            assert orig_nsp.normsubpathitems
             par_to_orig = {}
             for nspitem in orig_nsp:
                 par_to_orig[nspitem] = nspitem
